==> haskell-vector-algorithms-0.7.0.1-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.7.0.1
id: vector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
key: vector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
license: BSD3
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for vector arrays
category: Data
author: Dan Doel
exposed: True
exposed-modules:
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
abi: e7e47d08d14d887084a2c06396f160be
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/vector-algorithms-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/vector-algorithms-0.7.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/vector-algorithms-0.7.0.1
hs-libraries: HSvector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
include-dirs: /usr/lib/ghc-8.0.1/site-local/vector-algorithms-0.7.0.1/include
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-algorithms-0.7.0.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-vector-algorithms.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-algorithms
version: 0.7.0.1
id: vector-algorithms-0.7.0.1-5uWiEsia2ll7iojszUQtFk
key: vector-algorithms-0.7.0.1-5uWiEsia2ll7iojszUQtFk
license: BSD3
copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
           (c) 2015 Tim Baumann
maintainer: Dan Doel <dan.doel@gmail.com>
homepage: http://code.haskell.org/~dolio/
synopsis: Efficient algorithms for vector arrays
description:
    Efficient algorithms for vector arrays
category: Data
author: Dan Doel
exposed: True
exposed-modules:
    Data.Vector.Algorithms.Optimal Data.Vector.Algorithms.Insertion
    Data.Vector.Algorithms.Intro Data.Vector.Algorithms.Merge
    Data.Vector.Algorithms.Radix Data.Vector.Algorithms.Search
    Data.Vector.Algorithms.Heap Data.Vector.Algorithms.AmericanFlag
    Data.Vector.Algorithms.Tim
hidden-modules: Data.Vector.Algorithms.Common
abi: 29d1a5178e7c45d2aad4e08073e085fb
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/vector-algorithms-0.7.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/vector-algorithms-0.7.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/vector-algorithms-0.7.0.1
hs-libraries: HSvector-algorithms-0.7.0.1-5uWiEsia2ll7iojszUQtFk
include-dirs: /usr/lib/ghc-8.0.1/site-local/vector-algorithms-0.7.0.1/include
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    primitive-0.6.2.0-3HSsNCfUEEE4fjqDYVydYZ
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-vector-algorithms/html/vector-algorithms.haddock
haddock-html: /usr/share/doc/haskell-vector-algorithms/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
